==> tensorpc-0.13.0.tar.gz: tensorpc-0.13.0/tensorpc/examples/tutorials/02-components/2.21-DataFlexBox.md <==
## DataFlexBox


### Basic Usage 


```Python
from tensorpc.flow import mui, three, plus, appctx, mark_create_layout

class App:
    class Config(plus.AppInMemory.Config):
        height = "400px"

    def create_data(self, index: int, name: str,
        color_is_red: bool):
        return {
            "id": str(index),
            "name": name,
        }
    
    def create_many_datas(self, count: int):
        for i in range(count):
            if i % 2 == 0:
                yield self.create_data(i, f"name{i}", i % 2 == 0)
            else:
                yield self.create_data(i, f"sex{i}", i % 2 != 0)

    @mark_create_layout
    def my_layout(self):
        rows = list(self.create_many_datas(50))
        name = mui.Typography("name")
        name.set_override_props(value="name")
        child = mui.ListItemButton([
            mui.ListItemIcon(mui.IconType.Add),
            name,
        ])
        dbox = mui.DataFlexBox(child, rows).prop(width="100%", flex=1, secondaryIconButtonProps=[
            mui.IconButtonBaseProps(name="1", icon=mui.IconType.Delete, size="medium"),
            mui.IconButtonBaseProps(name="2", icon=mui.IconType.PlayArrow, size="medium"),
        ], variant="list", dense=False, disablePadding=True)
        child.event_click.on_standard(lambda x: print(x.keys)).configure(True)
        dbox.event_secondary_action_click.on_standard(lambda x: print(x))
        filter_input = mui.TextField("filter").prop(valueChangeTarget=(dbox, "filter"))
        dbox.prop(filterKey="name")
        return mui.VBox([
            filter_input,
            dbox,
        ]).prop(width="100%", height="100%", overflow="hidden")


```

==> tensorpc-0.14.0.tar.gz: tensorpc-0.14.0/tensorpc/examples/tutorials/02-components/2.21-DataFlexBox.md <==
## DataFlexBox


### Basic Usage 


```Python
from tensorpc.flow import mui, three, plus, appctx, mark_create_layout

class App:
    class Config(plus.AppInMemory.Config):
        height = "400px"

    def create_data(self, index: int, name: str,
        color_is_red: bool):
        return {
            "id": str(index),
            "name": name,
        }
    
    def create_many_datas(self, count: int):
        for i in range(count):
            if i % 2 == 0:
                yield self.create_data(i, f"name{i}", i % 2 == 0)
            else:
                yield self.create_data(i, f"sex{i}", i % 2 != 0)

    @mark_create_layout
    def my_layout(self):
        rows = list(self.create_many_datas(50))
        name = mui.Typography("name")
        name.bind_fields(value="name")
        child = mui.ListItemButton([
            mui.ListItemIcon(mui.IconType.Add),
            name,
        ])
        dbox = mui.DataFlexBox(child, rows).prop(width="100%", flex=1, secondaryIconButtonProps=[
            mui.IconButtonBaseProps(name="1", icon=mui.IconType.Delete, size="medium"),
            mui.IconButtonBaseProps(name="2", icon=mui.IconType.PlayArrow, size="medium"),
        ], variant="list", dense=False, disablePadding=True)
        child.event_click.on_standard(lambda x: print(x.keys)).configure(True)
        dbox.event_secondary_action_click.on_standard(lambda x: print(x))
        filter_input = mui.TextField("filter").prop(valueChangeTarget=(dbox, "filter"))
        dbox.prop(filterKey="name")
        return mui.VBox([
            filter_input,
            dbox,
        ]).prop(width="100%", height="100%", overflow="hidden")


```
